@@ -4,7 +4,7 @@
 
 ;; Maintainer: Nicolas P. Rougier <Nicolas.Rougier@inria.fr>
 ;; URL: https://github.com/rougier/nano-modeline
-;; Version: 0.7
+;; Version: 0.7.1
 ;; Package-Requires: ((emacs "27.1"))
 ;; Keywords: convenience, mode-line, header-line
 
@@ -48,6 +48,11 @@
 ;;
 ;;; NEWS:
 ;;
+;; Version 0.7.1
+;; - Fix a bug with mu4e-dashboard
+;; - Fix a bug in pdf view mode
+;; - Better org-capture mode
+;;
 ;; Version 0.7
 ;; - Prefix is now an option (none, status or icon)
 ;; - Prefix can be replaced by icons
@@ -220,12 +225,15 @@ This is useful (aesthetically) if the face of prefix uses a different background
     (imenu-list-mode        :mode-p nano-modeline-imenu-list-mode-p
                             :format nano-modeline-imenu-list-mode
                             :icon "") ;; nerd-font / oct-three-bars
+    (org-capture-mode       :mode-p nano-modeline-org-capture-mode-p
+                            :format nano-modeline-org-capture-mode
+                            :on-activate nano-modeline-org-capture-activate
+                            :on-inactivate nano-modeline-org-capture-inactivate
+                            :icon "") ;; nerd-font / oct-calendar
+
     (prog-mode              :mode-p nano-modeline-prog-mode-p
                             :format nano-modeline-prog-mode
                             :icon "") ;; nerd-font / oct-file-code
-    (mu4e-dashboard-mode    :mode-p nano-modeline-mu4e-dashboard-mode-p
-                            :format nano-modeline-mu4e-dashboard-mode
-                            :icon "") ;; nerd-font / oct-inbox
     (mu4e-compose-mode      :mode-p nano-modeline-mu4e-compose-mode-p
                             :format nano-modeline-mu4e-compose-mode
                             :icon "") ;; nerd-font / oct-pencil
@@ -241,6 +249,9 @@ This is useful (aesthetically) if the face of prefix uses a different background
     (mu4e-view-mode         :mode-p nano-modeline-mu4e-view-mode-p
                             :format nano-modeline-mu4e-view-mode
                             :icon "") ;; nerd-font / oct-comment
+    (mu4e-dashboard-mode    :mode-p nano-modeline-mu4e-dashboard-mode-p
+                            :format nano-modeline-mu4e-dashboard-mode
+                            :icon "") ;; nerd-font / oct-inbox
     (messages-mode          :mode-p nano-modeline-messages-mode-p
                             :format nano-modeline-messages-mode
                             :icon "") ;; nerd-font / oct-comment
@@ -296,11 +307,6 @@ This is useful (aesthetically) if the face of prefix uses a different background
     (org-agenda-mode        :mode-p nano-modeline-org-agenda-mode-p
                             :format nano-modeline-org-agenda-mode
                             :icon "") ;; nerd-font / oct-calendar
-    (org-capture-mode       :mode-p nano-modeline-org-capture-mode-p
-                            :format nano-modeline-org-capture-mode
-                            :on-activate nano-modeline-org-capture-activate
-                            :on-inactivate nano-modeline-org-capture-inactivate
-                            :icon "") ;; nerd-font / oct-calendar
     (org-clock-mode         :mode-p nano-modeline-org-clock-mode-p
                             :format nano-modeline-org-clock-mode
                             :on-activate nano-modeline-org-clock-activate
@@ -345,7 +351,7 @@ KEY mode name, for reference only. Easier to do lookups and/or replacements.
   :group 'nano-modeline)
 
 (defcustom nano-modeline-default-mode-format 'nano-modeline-default-mode
-  "Default mode to evaluate if no match could be found in `nano-modelines-mode-formats'"
+  "Default mode to evaluate if no match could be found in `nano-modeline-mode-formats'"
   :type 'function
   :group 'nano-modeline)
 
@@ -605,7 +611,7 @@ KEY mode name, for reference only. Easier to do lookups and/or replacements.
   (nano-modeline-render (plist-get (cdr (assoc 'org-capture-mode nano-modeline-mode-formats)) :icon)
                         "Capture"
                         (concat "(" (org-capture-get :description) ")")
-                        ""))
+                        "Finish: C-c C-c, refile: C-c C-w, cancel: C-c C-k "))
 
 (defun nano-modeline-org-capture-turn-off-header-line ()
   (setq-local header-line-format (default-value 'header-line-format))
@@ -888,7 +894,7 @@ depending on the version of mu4e."
     (mode-name   (nano-modeline-mode-name))
     (branch      (nano-modeline-vc-branch))
     (page-number (concat
-              (number-to-string (doc-view-current-page)) "/"
+                  (number-to-string (image-mode-window-get 'page)) "/"
               (or (ignore-errors
                 (number-to-string (doc-view-last-page-number)))
               "???"))))
@@ -906,7 +912,7 @@ depending on the version of mu4e."
     (mode-name   (nano-modeline-mode-name))
     (branch      (nano-modeline-vc-branch))
     (page-number (concat
-              (number-to-string (pdf-view-current-page)) "/"
+              (number-to-string (image-mode-window-get 'page)) "/"
               (or (ignore-errors
                 (number-to-string (pdf-cache-number-of-pages)))
               "???"))))
@@ -981,15 +987,15 @@ depending on the version of mu4e."
 
 (defun nano-modeline-imenu-list-mode (&optional icon)
   (let ((icon (or icon
-                  (plist-get (cdr (assoc 'text-mode nano-imenu-list-mode-formats)) :icon)))
+                  (plist-get (cdr (assoc 'imenu-list-mode nano-modeline-mode-formats)) :icon)))
         ;; We take into account the case of narrowed buffers
-        (buffer-name (buffer-name imenu-list--displayed-buffer)
+        (buffer-name (buffer-name imenu-list--displayed-buffer))
         (branch      (nano-modeline-vc-branch))
         (position    (format-mode-line "%l:%c")))
     (nano-modeline-render icon
                           buffer-name
                           "(imenu list)"
-                          ""))))
+                          "")))
 
 ;; ---------------------------------------------------------------------
 (with-eval-after-load 'deft
@@ -1146,7 +1152,14 @@ below or a buffer local variable 'no-mode-line'."
   ;;  -> see https://github.com/rougier/nano-modeline/issues/24
   ;; (add-hook 'window-configuration-change-hook #'nano-modeline-update-windows)
 
-  (force-mode-line-update t))
+  (force-mode-line-update t)
+
+  ;; `eldoc-minibuffer-message' changes `mode-line-format' but
+  ;; nano-modeline when `nano-modeline-position' is `top' only displays
+  ;; the header-line.
+  ;; -> see https://github.com/rougier/nano-modeline/issues/36
+  (when (eq nano-modeline-position 'top)
+    (setq eldoc-message-function #'message)))
 
 (defun nano-modeline-mode--inactivate ()
   "Inactivate nano mode line and restored default mode-line"
